@@ -18,8 +18,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope.concepts import concepts
+from googlecloudsdk.command_lib.container.binauthz import arg_parsers
 from googlecloudsdk.command_lib.kms import flags as kms_flags
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs as presentation_specs_lib
@@ -31,12 +31,13 @@ def _GetNoteResourceSpec():
       resource_name='note',
       projectsId=concepts.ResourceParameterAttributeConfig(
           name='project',
-          help_text=('The Container Analysis project for the {resource}.'),
+          help_text='The Container Analysis project for the {resource}.',
       ),
       notesId=concepts.ResourceParameterAttributeConfig(
           name='note',
           help_text='The Container Analysis Note ID for the {resource}.',
-      ))
+      ),
+  )
 
 
 def _FormatArgName(base_name, positional):
@@ -46,12 +47,14 @@ def _FormatArgName(base_name, positional):
     return '--' + base_name.replace('_', '-').lower()
 
 
-def GetAuthorityNotePresentationSpec(group_help,
-                                     base_name='authority-note',
-                                     required=True,
-                                     positional=True,
-                                     use_global_project_flag=False):
-  """Construct a resource spec for an attestation authority note flag."""
+def GetNotePresentationSpec(
+    group_help,
+    base_name='note',
+    required=True,
+    positional=True,
+    use_global_project_flag=False,
+):
+  """Construct a resource spec for a Container Analysis note flag."""
   flag_overrides = None
   if not use_global_project_flag:
     flag_overrides = {
@@ -74,14 +77,17 @@ def _GetAttestorResourceSpec():
       attestorsId=concepts.ResourceParameterAttributeConfig(
           name='name',
           help_text='The ID of the {resource}.',
-      ))
+      ),
+  )
 
 
-def GetAttestorPresentationSpec(group_help,
-                                base_name='attestor',
-                                required=True,
-                                positional=True,
-                                use_global_project_flag=True):
+def GetAttestorPresentationSpec(
+    group_help,
+    base_name='attestor',
+    required=True,
+    positional=True,
+    use_global_project_flag=True,
+):
   """Construct a resource spec for an attestor flag."""
   flag_overrides = None
   if not use_global_project_flag:
@@ -121,11 +127,13 @@ def _GetCryptoKeyVersionResourceSpec():
   )
 
 
-def GetCryptoKeyVersionPresentationSpec(group_help,
-                                        base_name='keyversion',
-                                        required=True,
-                                        positional=True,
-                                        use_global_project_flag=True):
+def GetCryptoKeyVersionPresentationSpec(
+    group_help,
+    base_name='keyversion',
+    required=True,
+    positional=True,
+    use_global_project_flag=True,
+):
   """Construct a resource spec for a CryptoKeyVersion flag."""
   flag_overrides = None
   if not use_global_project_flag:
@@ -151,8 +159,11 @@ def AddArtifactUrlFlag(parser, required=True):
       '--artifact-url',
       required=required,
       type=str,
-      help=('Container URL. May be in the `gcr.io/repository/image` format,'
-            ' or may optionally contain the `http` or `https` scheme'))
+      help=(
+          'Container URL. May be in the `gcr.io/repository/image` format,'
+          ' or may optionally contain the `http` or `https` scheme'
+      ),
+  )
 
 
 def _GetPlatformResourceSpec():
@@ -162,7 +173,9 @@ def _GetPlatformResourceSpec():
       api_version='v1',
       projectsId=concepts.DEFAULT_PROJECT_ATTRIBUTE_CONFIG,
       platformsId=concepts.ResourceParameterAttributeConfig(
-          name='platform', help_text='The platform.'))
+          name='platform', help_text='The platform.'
+      ),
+  )
 
 
 def AddPlatformResourceArg(parser, verb):
@@ -181,7 +194,8 @@ def AddPlatformResourceArg(parser, verb):
       'platform_resource_name',
       _GetPlatformResourceSpec(),
       'The platform whose policies {}.'.format(verb),
-      required=True).AddToParser(parser)
+      required=True,
+  ).AddToParser(parser)
 
 
 def _GetPlatformPolicyResourceSpec():
@@ -192,10 +206,15 @@ def _GetPlatformPolicyResourceSpec():
       projectsId=concepts.DEFAULT_PROJECT_ATTRIBUTE_CONFIG,
       platformsId=concepts.ResourceParameterAttributeConfig(
           name='platform',
-          help_text='The platform that the {resource} belongs to. '
-          'PLATFORM must be one of the following: cloudRun, gke.'),
+          help_text=(
+              'The platform that the {resource} belongs to. '
+              'PLATFORM must be one of the following: cloudRun, gke.'
+          ),
+      ),
       policyId=concepts.ResourceParameterAttributeConfig(
-          name='policy', help_text='The ID of the {resource}.'))
+          name='policy', help_text='The ID of the {resource}.'
+      ),
+  )
 
 
 def AddPlatformPolicyResourceArg(parser, verb):
@@ -213,11 +232,79 @@ def AddPlatformPolicyResourceArg(parser, verb):
   ).AddToParser(parser)
 
 
-def AddPodFileContentArg(parser):
-  """Adds a resource argument for a Pod from a JSON or YAML file."""
-  parser.add_argument(
+def AddEvaluationUnitArg(parser):
+  """Adds a resource argument from file or from one or more images."""
+  evaluation_unit_group = parser.add_group(mutex=True, required=True)
+  evaluation_unit_group.add_argument(
       '--resource',
-      required=True,
-      type=arg_parsers.YAMLFileContents(),
-      help='The JSON or YAML file containing the Pod to evaluate.',
+      required=False,
+      type=arg_parsers.ResourceFileName,
+      help=(
+          'The JSON or YAML file containing the Kubernetes resource to'
+          ' evaluate.'
+      ),
+  )
+  evaluation_unit_group.add_argument(
+      '--image',
+      required=False,
+      action='append',
+      help=(
+          'The image to evaluate. If the policy being evaluated has scoped'
+          ' checksets, this mode of evaluation will always use the default'
+          ' (unscoped) checkset.'
+      ),
+  )
+
+
+def AddNoUploadArg(parser):
+  """Adds a --no-upload flag to parser."""
+  parser.add_argument(
+      '--no-upload',
+      action='store_true',
+      default=False,
+      help=(
+          'Do not upload the generated attestations to the image registry'
+          ' (using Sigstore tag conventions). Note, attestations are never'
+          ' uploaded to the transparency log.'
+      ),
+  )
+
+
+def AddOutputFileArg(parser):
+  """Adds the output file argument to parser."""
+  parser.add_argument(
+      '--output-file',
+      help=(
+          'If a resource is provided and deemed to be conformant, attestations'
+          ' will be added as annotations on the resource and writen back to'
+          ' this file path in the same format as the input file.'
+      ),
+  )
+
+
+def AddDockerCredsArgs(parser):
+  """Adds the docker creds args to parser."""
+  docker_args_group = parser.add_group(mutex=False, required=False)
+  docker_args_group.add_argument(
+      '--use-docker-creds',
+      required=False,
+      action='store_true',
+      default=False,
+      help=(
+          'Whether to use the configuration file where Docker saves'
+          ' authentication credentials when uploading attestations to the'
+          ' registry. If this flag is not passed, or valid credentials are not'
+          ' found, an OAuth2 token for the active gcloud account is used. See'
+          ' https://cloud.google.com/artifact-registry/docs/docker/authentication'
+          ' for more information.'
+      ),
+  )
+  docker_args_group.add_argument(
+      '--docker-config-dir',
+      required=False,
+      help=(
+          'Override the directory where the Docker configuration file is'
+          ' searched for. Credentials are pulled from the config.json file'
+          ' under this directory. Defaults to $HOME/.docker.'
+      ),
   )
