@@ -1439,7 +1439,7 @@ pipeline that involve access to the data field will fail as persistent errors.
               includes_json=True,
           ),
           min_length=1,
-          custom_delim_char='|',
+          custom_delim_char='#',
       ),
       action=arg_parsers.UpdateAction,
       required=required,
@@ -1474,7 +1474,7 @@ Examples:
               },
               includes_json=True,
           ),
-          custom_delim_char='|',
+          custom_delim_char='#',
       ),
       help=help_text,
       metavar='transformation_template=TRANSFORMATION_TEMPLATE',
