@@ -119,7 +119,8 @@ def SplitMultiline(log_generator, allow_multiline=False):
 def _EntryToDict(log_entry):
   """Converts a log entry to a dictionary."""
   output = {}
-  output['severity'] = log_entry.severity.name
+  output[
+      'severity'] = log_entry.severity.name if log_entry.severity else 'DEFAULT'
   output['timestamp'] = log_entry.timestamp
   label_attributes = _GetLabelAttributes(log_entry)
   output['task_name'] = label_attributes['task_name']
@@ -150,10 +151,6 @@ def _GetLabelAttributes(log_entry):
   """Reads the label attributes of the given log entry."""
   label_attributes = {'task_name': 'unknown_task'}
 
-  # TODO(b/36233192): task_name will not be available in labels but only in
-  # resource_labels. Given that logs have 30 day retention, we should eventually
-  # remove the code that checks for task_name and ml.googleapis.com/task_name in
-  # labels.
   labels = _ToDict(log_entry.labels)
   resource_labels = {} if not log_entry.resource else _ToDict(
       log_entry.resource.labels)
