@@ -20,6 +20,6 @@ from googlecloudsdk.calliope import base
 # TODO(b/321801975) make command public after suv2 launch.
 @base.UniverseCompatible
 @base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class ContentSecurity(base.Group):
   """Get/add/remove MCP content security."""
