@@ -323,6 +323,7 @@ def AddBaseArgs(parser):
   flags.AddEnableGooglePrivatePath(parser, show_negated_in_help=True)
   flags.AddThreadsPerCore(parser)
   flags.AddEnableDataCache(parser)
+  flags.AddEnableAutoUpgrade(parser)
   flags.AddRecreateReplicasOnPrimaryCrash(parser)
   psc_update_group = parser.add_mutually_exclusive_group()
   flags.AddAllowedPscProjects(psc_update_group)
@@ -349,12 +350,12 @@ def AddBaseArgs(parser):
   flags.AddClearPSCNetworkAttachmentUri(psc_na_uri_update_group)
   flags.AddInstanceType(parser)
   flags.AddNodeCount(parser)
-  flags.AddActiveDirectoryMode(parser, hidden=True)
-  flags.AddActiveDirectorySecretManagerKey(parser, hidden=True)
-  flags.AddActiveDirectoryOrganizationalUnit(parser, hidden=True)
-  flags.AddActiveDirectoryDNSServers(parser, hidden=True)
-  flags.ClearActiveDirectoryDNSServers(parser, hidden=True)
-  flags.AddClearActiveDirectory(parser, hidden=True)
+  flags.AddActiveDirectoryMode(parser)
+  flags.AddActiveDirectorySecretManagerKey(parser)
+  flags.AddActiveDirectoryOrganizationalUnit(parser)
+  flags.AddActiveDirectoryDNSServers(parser)
+  flags.ClearActiveDirectoryDNSServers(parser)
+  flags.AddClearActiveDirectory(parser)
   flags.AddFinalBackup(parser)
   flags.AddFinalbackupRetentionDays(parser)
   flags.AddEnableConnectionPooling(parser)
@@ -364,6 +365,9 @@ def AddBaseArgs(parser):
   psc_update_auto_connections_group = parser.add_mutually_exclusive_group()
   flags.AddPscAutoConnections(psc_update_auto_connections_group)
   flags.AddClearPscAutoConnections(psc_update_auto_connections_group)
+  flags.AddServerCaMode(parser)
+  flags.AddServerCaPool(parser)
+  flags.AddReadPoolAutoScaleConfig(parser)
 
 
 def AddBetaArgs(parser):
@@ -373,18 +377,14 @@ def AddBetaArgs(parser):
   labels_util.AddUpdateLabelsFlags(parser, enable_clear=True)
   flags.AddReplicationLagMaxSecondsForRecreate(parser)
   flags.AddReconcilePsaNetworking(parser)
-  flags.AddEnableAcceleratedReplicaMode(parser)
-  flags.AddEnableAutoUpgrade(parser)
-  flags.AddServerCaMode(parser, hidden=True)
-  flags.AddServerCaPool(parser, hidden=True)
   unc_mappings_group = parser.add_mutually_exclusive_group(hidden=True)
   flags.AddUncMappings(unc_mappings_group)
   flags.AddClearUncMappings(unc_mappings_group)
 
 
-def AddAlphaArgs(parser):
+def AddAlphaArgs(unused_parser):
   """Adds alpha args and flags to the parser."""
-  flags.AddReadPoolAutoScaleConfig(parser, hidden=True)
+  pass
 
 
 def IsBetaOrNewer(release_track):
@@ -515,14 +515,6 @@ def RunBasePatchCommand(args, release_track):
             ' arguments excluding gcloud wide flags'
         )
 
-  if args.IsKnownAndSpecified('enable_accelerated_replica_mode'):
-    if not api_util.InstancesV1Beta4.IsMysqlDatabaseVersion(
-        original_instance_resource.databaseVersion
-    ):
-      raise exceptions.ArgumentError(
-          '--enable-accelerated-replica-mode is only supported for MySQL.'
-      )
-
   patch_instance = command_util.InstancesV1Beta4.ConstructPatchInstanceFromArgs(
       sql_messages,
       args,
