@@ -31,8 +31,10 @@ from __future__ import unicode_literals
 
 import six
 
-NO_URLS_MATCHED_GENERIC = 'No URLs matched'
-NO_URLS_MATCHED_TARGET = 'No URLs matched: %s'
+NO_URLS_MATCHED_PREFIX = 'No URLs matched'
+NO_URLS_MATCHED_GENERIC = (NO_URLS_MATCHED_PREFIX +
+                           '. Do the files you\'re operating on exist?')
+NO_URLS_MATCHED_TARGET = NO_URLS_MATCHED_PREFIX + ': %s'
 
 if six.PY3:
   # StandardError was removed, so use the base exception type instead
@@ -89,6 +91,11 @@ class ControlCException(Exception):
   pass
 
 
+class GcloudStorageTranslationError(Exception):
+  """Exception raised when a gsutil command can't be translated to gcloud."""
+  pass
+
+
 class HashMismatchException(Exception):
   """Exception raised when data integrity validation fails."""
   pass
@@ -135,3 +142,14 @@ class InvalidUrlError(Exception):
 
   def __str__(self):
     return 'InvalidUrlError: %s' % self.message
+
+
+class ExternalBinaryError(Exception):
+  """Exception raised when gsutil runs an external binary, and it fails."""
+
+  def __init__(self, message):
+    Exception.__init__(self, message)
+    self.message = message
+
+  def __repr__(self):
+    return 'ExternalBinaryError: %s' % self.message
